@@ -15,7 +15,7 @@ use unicode_segmentation::UnicodeSegmentation;
 // possible to create this type outside of this module, hence enforcing the use of `parse`. This
 // ensures that every string stored in this type satisfies the validation criteria checked by
 // `parse`.
-#[derive(Debug, Clone, PartialEq, Eq, sqlx::Type)]
+#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord, Hash, sqlx::Type)]
 #[sqlx(transparent)]
 pub struct ValidName(String);
 
@@ -57,7 +57,7 @@ impl<'de> serde::Deserialize<'de> for ValidName {
         D: serde::Deserializer<'de>,
     {
         let buf = String::deserialize(deserializer)?;
-        // Aaaah I don't like this clone at all... If stuff is slow, figure this out.
+        // Aah I don't like this clone at all... If stuff is slow, figure this out.
         // I could remove the context, but it's nice to inform the user what's wrong. On the other
         // hand, if users use our clients, this parsing can't fail.
         ValidName::parse(buf.clone())
